.. role:: hidden
    :class: hidden-section


botorch.sampling
========================================================
.. automodule:: botorch.sampling


Monte-Carlo Samplers
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.sampling.samplers
    :members:

Pairwise Monte-Carlo Samplers
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.sampling.pairwise_samplers
    :members:

QMC Base Functionality
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: botorch.sampling.qmc
    :members:
